@@ -10,7 +10,6 @@
 #' 'leg_pos2', 'leg_title', 'leg_title_cex', 'leg_val_cex', 'val_order',
 #' 'leg_no_data', 'leg_frame'))
 #'
-#' @importFrom methods is
 #' @keywords internal
 #' @export
 #' @return x is (invisibly) returned.
@@ -54,12 +53,12 @@ mf_prop_typo <- function(x, var,
                          leg_frame = c(FALSE, FALSE),
                          add = TRUE) {
   # default
-  op <- par(mar = .gmapsf$args$mar, no.readonly = TRUE)
+  op <- par(mar = getOption("mapsf.mar"), no.readonly = TRUE)
   lend <- par("lend")
 
   on.exit(par(op))
-  bg <- .gmapsf$args$bg
-  fg <- .gmapsf$args$fg
+  bg <- getOption("mapsf.bg")
+  fg <- getOption("mapsf.fg")
   if (missing(border)) border <- fg
 
   var2 <- var[2]
